@@ -167,11 +167,19 @@ impl Dispatcher {
                 dst_location,
                 msg,
                 sender,
+                known_keys,
             } => {
                 self.core
                     .read()
                     .await
-                    .handle_non_blocking_message(msg_id, msg_authority, dst_location, msg, sender)
+                    .handle_non_blocking_message(
+                        msg_id,
+                        msg_authority,
+                        dst_location,
+                        msg,
+                        sender,
+                        known_keys,
+                    )
                     .await
             }
             // Non-data node msg that requires locking
@@ -180,12 +188,11 @@ impl Dispatcher {
                 msg_id,
                 msg_authority,
                 msg,
-                known_keys,
             } => {
                 self.core
                     .write()
                     .await
-                    .handle_blocking_message(sender, msg_id, msg_authority, msg, known_keys)
+                    .handle_blocking_message(sender, msg_id, msg_authority, msg)
                     .await
             }
             Command::HandleSystemMessage {
@@ -236,15 +243,17 @@ impl Dispatcher {
             Command::HandleConnectionLost(addr) => {
                 self.core.read().await.handle_connection_lost(addr)
             }
-            Command::HandlePeerLost(addr) => self.core.read().await.handle_peer_lost(&addr),
+            Command::HandlePeerLost(addr) => self.core.read().await.handle_peer_lost(&addr).await,
             Command::HandleDkgOutcome {
                 section_auth,
                 outcome,
-            } => self
-                .core
-                .write()
-                .await
-                .handle_dkg_outcome(section_auth, outcome),
+            } => {
+                self.core
+                    .write()
+                    .await
+                    .handle_dkg_outcome(section_auth, outcome)
+                    .await
+            }
             Command::HandleDkgFailure(signeds) => self
                 .core
                 .write()
@@ -277,7 +286,11 @@ impl Dispatcher {
                 Ok(vec![])
             }
             Command::SetJoinsAllowed(joins_allowed) => {
-                self.core.read().await.set_joins_allowed(joins_allowed)
+                self.core
+                    .read()
+                    .await
+                    .set_joins_allowed(joins_allowed)
+                    .await
             }
             Command::ProposeOnline {
                 mut peer,
@@ -292,7 +305,7 @@ impl Dispatcher {
                     .make_online_proposal(peer, previous_name, dst_key)
                     .await
             }
-            Command::ProposeOffline(name) => self.core.read().await.propose_offline(name),
+            Command::ProposeOffline(name) => self.core.read().await.propose_offline(name).await,
             Command::StartConnectivityTest(name) => {
                 let msg = {
                     let core = self.core.read().await;
